@@ -3,10 +3,10 @@ use strict;
 use warnings;
 use base 'Class::Accessor::Grouped';
 
-__PACKAGE__->mk_group_accessors('inherited', 'basefield', 'undefined');
+__PACKAGE__->mk_group_accessors('inherited', 'basefield');
 
 sub new {
-  return bless {}, shift;
+    return bless {}, shift;
 };
 
 1;
